﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Infragistics;
using System.Collections.ObjectModel;

namespace CustomScheduleTest
{
	public class ScheduleData
	{
		private ObservableCollection<ResourceDataItem> _resources;
		private ObservableCollection<CalendarDataItem> _calendars;
		private ObservableCollection<AppointmentDataItem> _appointments;

		public ScheduleData()
		{
			_resources = new ObservableCollection<ResourceDataItem>();
			_calendars = new ObservableCollection<CalendarDataItem>();
			_appointments = new ObservableCollection<AppointmentDataItem>();
		}

		public ObservableCollection<ResourceDataItem> Resources
		{
			get { return _resources; }
		}

		public ObservableCollection<CalendarDataItem> Calendars
		{
			get { return _calendars; }
		}

		public ObservableCollection<AppointmentDataItem> Appointments
		{
			get { return _appointments; }
		}
	}

	public class DataItemBase : PropertyChangeNotifier
	{
		protected bool SetField<T>(ref T member, T value, string propertyName)
		{
			if (EqualityComparer<T>.Default.Equals(member, value))
				return false;

			member = value;
			this.OnPropertyChanged(propertyName);
			return true;
		}
	}

	public class ResourceDataItem : DataItemBase
	{
		private string _id;
		public string Id
		{
			get { return _id; }
			set { this.SetField(ref _id, value, "Id"); }
		}

		private string _name;
		public string Name
		{
			get { return _name; }
			set { this.SetField(ref _name, value, "Name"); }
		}
	}

	public class CalendarDataItem : DataItemBase
	{
		private string _id;
		public string Id
		{
			get { return _id; }
			set { this.SetField(ref _id, value, "Id"); }
		}

		private string _name;
		public string Name
		{
			get { return _name; }
			set { this.SetField(ref _name, value, "Name"); }
		}

		private string _owningResourceId;
		public string OwningResourceId
		{
			get { return _owningResourceId; }
			set { this.SetField(ref _owningResourceId, value, "OwningResourceId"); }
		}

	}

	public class AppointmentDataItem : DataItemBase
	{
		private string _id;
		public string Id
		{
			get { return _id; }
			set { this.SetField(ref _id, value, "Id"); }
		}

		private string _owningResourceId;
		public string OwningResourceId
		{
			get { return _owningResourceId; }
			set { this.SetField(ref _owningResourceId, value, "OwningResourceId"); }
		}

		private string _owningCalendarId;
		public string OwningCalendarId
		{
			get { return _owningCalendarId; }
			set { this.SetField(ref _owningCalendarId, value, "OwningCalendarId"); }
		}

		private DateTime _start;
		public DateTime Start
		{
			get { return _start; }
			set { this.SetField(ref _start, value, "Start"); }
		}

		private DateTime _end;
		public DateTime End
		{
			get { return _end; }
			set { this.SetField(ref _end, value, "End"); }
		}

		private string _subject;
		public string Subject
		{
			get { return _subject; }
			set { this.SetField(ref _subject, value, "Subject"); }
		}

		private string _description;
		public string Description
		{
			get { return _description; }
			set { this.SetField(ref _description, value, "Description"); }
		}

		private string _comments;
		public string Comments
		{
			get { return _comments; }
			set { this.SetField(ref _comments, value, "Comments"); }
		}
	}
}
